@@ -21,7 +21,7 @@
 #include "udevqtdevice.h"
 #include "udevqt_p.h"
 
-#include <QtCore/QByteArray>
+#include <QByteArray>
 
 namespace UdevQt {
 
@@ -74,7 +74,7 @@ QString DevicePrivate::decodePropertyValue(const QByteArray &encoded) const
 }
 
 Device::Device()
-    : d(0)
+    : d(nullptr)
 {
 }
 
@@ -83,7 +83,7 @@ Device::Device(const Device &other)
     if (other.d) {
         d = new DevicePrivate(other.d->udev);
     } else {
-        d = 0;
+        d = nullptr;
     }
 }
 
@@ -103,7 +103,7 @@ Device &Device::operator=(const Device &other)
         return *this;
     if (!other.d) {
         delete d;
-        d = 0;
+        d = nullptr;
         return *this;
     }
     if (!d) {
@@ -117,7 +117,7 @@ Device &Device::operator=(const Device &other)
 
 bool Device::isValid() const
 {
-    return (d != 0);
+    return (d != nullptr);
 }
 
 QString Device::subsystem() const
